==> tasks-v1.8.8.zip: tasks/messages/tr/base.php <==
<?php

return [
    '<strong>Create</strong> task list' => 'Görev listesi oluştur',
    '<strong>Edit</strong> task list' => 'Görev listesini düzenle',
    'Accept Task' => 'Görevi kabul et',
    'Add task' => 'Görev ekle',
    'All Day' => 'Tüm gün',
    'Close' => 'Kapat',
    'Color' => 'Renk',
    'Created by me' => 'Açtıklarım',
    'Date' => 'Tarih',
    'Delete' => 'Sil',
    'Description' => 'Açıklama',
    'Edit' => 'Düzenle',
    'End' => 'Son',
    'End Date' => 'Bitiş tarihi',
    'End Time' => 'Bitiş Zamanı',
    'End time must be after start time!' => 'Bitiş saati başlangıç ​​zamanından sonra olmalıdır!',
    'Filter' => 'Filtre',
    'General' => 'Genel',
    'General Settings' => 'Genel Ayarlar',
    'Overview' => 'Genel Bakış',
    'Pending' => 'Onay bekliyor',
    'Reminder' => 'Hatırlatıcı',
    'Sort Order' => 'Sıralama',
    'Sort order' => 'Sırala',
    'Spaces' => 'Mekanlar',
    'Start' => 'Başla',
    'Start Date' => 'Başlangıç tarihi',
    'Start Time' => 'Başlangıç Zamanı',
    'Status' => 'Durum',
    'Tasks' => 'Görevler',
    'Time Zone' => 'Saat Dilimi',
    'Title' => 'Başlık',
    'View Online' => 'Çevrimiçi Görüntüleme',
    'You have insufficient permissions to perform that operation!' => 'Bu işlemi gerçekleştirmek için yeterli izinlere sahip değilsiniz!',
    '{userName} finished task {task}.' => '{task} Görev sona erdi {userName} .',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>Edit</strong> task' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '',
    'Anyone can work on this task!' => '',
    'Assign myself' => '',
    'Assign users' => '',
    'Assigned' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments:' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline at' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Do you really want to delete this task?' => '',
    'Don\'t add to calendar' => '',
    'Drag entry' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task can only be processed by assigned and responsible users.' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'Unsorted' => '',
    'You are assigned!' => '',
    'You are responsible!' => '',
    'Your Reminder for task {task}' => '',
    'ending Review' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/tr/base.php <==
<?php

return [
    '<strong>Create</strong> task list' => 'Görev listesi oluştur',
    '<strong>Edit</strong> task list' => 'Görev listesini düzenle',
    'Accept Task' => 'Görevi kabul et',
    'Add task' => 'Görev ekle',
    'All Day' => 'Tüm gün',
    'Close' => 'Kapat',
    'Color' => 'Renk',
    'Created by me' => 'Açtıklarım',
    'Date' => 'Tarih',
    'Delete' => 'Sil',
    'Description' => 'Açıklama',
    'Edit' => 'Düzenle',
    'End' => 'Son',
    'End Date' => 'Bitiş tarihi',
    'End Time' => 'Bitiş Zamanı',
    'End time must be after start time!' => 'Bitiş saati başlangıç ​​zamanından sonra olmalıdır!',
    'Filter' => 'Filtre',
    'General' => 'Genel',
    'General Settings' => 'Genel Ayarlar',
    'Overview' => 'Genel Bakış',
    'Pending' => 'Onay bekliyor',
    'Reminder' => 'Hatırlatıcı',
    'Sort Order' => 'Sıralama',
    'Sort order' => 'Sırala',
    'Spaces' => 'Mekanlar',
    'Start' => 'Başla',
    'Start Date' => 'Başlangıç tarihi',
    'Start Time' => 'Başlangıç Zamanı',
    'Status' => 'Durum',
    'Tasks' => 'Görevler',
    'Time Zone' => 'Saat Dilimi',
    'Title' => 'Başlık',
    'View Online' => 'Çevrimiçi Görüntüleme',
    'You have insufficient permissions to perform that operation!' => 'Bu işlemi gerçekleştirmek için yeterli izinlere sahip değilsiniz!',
    '{userName} finished task {task}.' => '{task} Görev sona erdi {userName} .',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>Edit</strong> task' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Assign myself' => '',
    'Assign users' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Do you really want to delete this task?' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request Review' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'Unsorted' => '',
    'Your Reminder for task {task}' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{displayName} is task creator' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];
